==> qmmp-1.1.9-1-src.tar.xz: qmmp-1.1.9/src/plugins/Output/qtmultimedia/translations/qtmultimedia_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>OutputQtMultimediaFactory</name>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="33"/>
        <source>Qt Multimedia Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="58"/>
        <source>About Qt Multimedia Output Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="59"/>
        <source>Qmmp Qt Multimedia Output Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="60"/>
        <source>Written by: Ivan Ponomarev &lt;ivantrue@gmail.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Qt Multimedia Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="46"/>
        <source>Device:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp-1.1.12-1-src.tar.xz: qmmp-1.1.12/src/plugins/Output/qtmultimedia/translations/qtmultimedia_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>OutputQtMultimediaFactory</name>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="33"/>
        <source>Qt Multimedia Plugin</source>
        <translation>Módulo Qt multimedios</translation>
    </message>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="58"/>
        <source>About Qt Multimedia Output Plugin</source>
        <translation>Acerca del Módulo Multimedios Qt</translation>
    </message>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="59"/>
        <source>Qmmp Qt Multimedia Output Plugin</source>
        <translation>Módulo de Salida de Multimedios Qt de Qmmp</translation>
    </message>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="60"/>
        <source>Written by: Ivan Ponomarev &lt;ivantrue@gmail.com&gt;</source>
        <translation>Escrito por: Ivan Ponomarev &lt;ivantrue@gmail.com&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Qt Multimedia Plugin Settings</source>
        <translation>Configuración de Módulo de Salida de Multimedios Qt</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="46"/>
        <source>Device:</source>
        <translation>Dispositivo:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Default</source>
        <translation>Predeterminado</translation>
    </message>
</context>
</TS>
